@@ -4,6 +4,7 @@ libtmux.exc
 ~~~~~~~~~~~
 
 """
+
 import typing as t
 
 from libtmux._internal.query_list import ObjectDoesNotExist
@@ -38,7 +39,7 @@ class TmuxObjectDoesNotExist(ObjectDoesNotExist):
         if all(arg is not None for arg in [obj_key, obj_id, list_cmd, list_extra_args]):
             return super().__init__(
                 f"Could not find {obj_key}={obj_id} for {list_cmd} "
-                f'{list_extra_args if list_extra_args is not None else ""}'
+                f'{list_extra_args if list_extra_args is not None else ""}',
             )
         return super().__init__("Could not find object")
 
@@ -51,7 +52,10 @@ class BadSessionName(LibTmuxException):
     """Disallowed session name for tmux (empty, contains periods or colons)."""
 
     def __init__(
-        self, reason: str, session_name: t.Optional[str] = None, *args: object
+        self,
+        reason: str,
+        session_name: t.Optional[str] = None,
+        *args: object,
     ):
         msg = f"Bad session name: {reason}"
         if session_name is not None:
@@ -129,3 +133,33 @@ class NoWindowsExist(WindowError):
 
     def __init__(self, *args: object):
         return super().__init__("No windows exist for object")
+
+
+class AdjustmentDirectionRequiresAdjustment(LibTmuxException, ValueError):
+    """If *adjustment_direction* is set, *adjustment* must be set."""
+
+    def __init__(self) -> None:
+        super().__init__("adjustment_direction requires adjustment")
+
+
+class WindowAdjustmentDirectionRequiresAdjustment(
+    WindowError, AdjustmentDirectionRequiresAdjustment
+):
+    """ValueError for :meth:`libtmux.Window.resize_window`."""
+
+    pass
+
+
+class PaneAdjustmentDirectionRequiresAdjustment(
+    WindowError, AdjustmentDirectionRequiresAdjustment
+):
+    """ValueError for :meth:`libtmux.Pane.resize_pane`."""
+
+    pass
+
+
+class RequiresDigitOrPercentage(LibTmuxException, ValueError):
+    """Requires digit (int or str digit) or a percentage."""
+
+    def __init__(self) -> None:
+        super().__init__("Requires digit (int or str digit) or a percentage.")
