@@ -4,6 +4,7 @@ libtmux.pane
 ~~~~~~~~~~~~
 
 """
+
 import dataclasses
 import logging
 import typing as t
@@ -336,12 +337,10 @@ class Pane(Obj):
         self,
         cmd: str,
         get_text: "t.Literal[True]",
-    ) -> t.Union[str, t.List[str]]:
-        ...
+    ) -> t.Union[str, t.List[str]]: ...
 
     @overload
-    def display_message(self, cmd: str, get_text: "t.Literal[False]") -> None:
-        ...
+    def display_message(self, cmd: str, get_text: "t.Literal[False]") -> None: ...
 
     def display_message(
         self,
@@ -500,12 +499,14 @@ class Pane(Obj):
         ----------
         attach : bool, optional
             Attach / select pane after creation.
-        vertical : bool, optional
-            split vertically
         start_directory : str, optional
             specifies the working directory in which the new pane is created.
+        vertical : bool, optional
+            split vertically
         percent: int, optional
             percentage to occupy with respect to current pane
+        environment: dict, optional
+            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
 
         Notes
         -----
